@@ -556,7 +556,10 @@ class TabularModel:
         self.model.train()
         if self.config.auto_lr_find and (not self.config.fast_dev_run):
             logger.info("Auto LR Find Started")
-            self.trainer.tune(self.model, train_loader, val_loader)
+            result = self.trainer.tune(self.model, train_loader, val_loader)
+            logger.info(
+                f"Suggested LR: {result['lr_find'].suggestion()}. For plot and detailed analysis, use `find_learning_rate` method."
+            )
             # Parameters in models needs to be initialized again after LR find
             self.model.data_aware_initialization(self.datamodule)
         self.model.train()
@@ -838,7 +841,7 @@ class TabularModel:
                 metrics = [torchmetrics.functional.accuracy]
                 metrics_params = [
                     {
-                        "task": "binary" if inferred_config.output_dim == 2 else "multiclass",
+                        "task": "multiclass",
                         "num_classes": inferred_config.output_dim,
                     }
                 ]
@@ -846,7 +849,7 @@ class TabularModel:
                 for i, mp in enumerate(metrics_params):
                     if "task" not in mp:
                         # For classification task, output_dim == number of classses
-                        metrics_params[i]["task"] = "binary" if inferred_config.output_dim == 2 else "multiclass"
+                        metrics_params[i]["task"] = "multiclass"
                     if "num_classes" not in mp:
                         metrics_params[i]["num_classes"] = inferred_config.output_dim
         # Forming partial callables using metrics and metric params
